==> tecfy_core_package-1.0.10.tar.gz: lib/views/components/general/data_table.componenet.dart <==
part of tecfy_core_client_package;

class AppDataTable extends StatefulWidget {
  final List<Map<String, dynamic>> data;
  final List<Property> columns;
  const AppDataTable({Key? key, required this.columns, required this.data})
      : super(key: key);

  @override
  _AppDataTableState createState() => _AppDataTableState();
}

class _AppDataTableState extends State<AppDataTable> {
  bool sortAscending = true;
  int? sortColumnIndex;
  @override
  Widget build(BuildContext context) {
    return DataTable(
      columnSpacing: 1,
      dividerThickness: 0.5,
      horizontalMargin: 1,
      showBottomBorder: false,
      sortAscending: sortAscending,
      sortColumnIndex: sortColumnIndex,
      columns: widget.columns
          .map<DataColumn>((h) => _getHeaderCell(h.nameAr,
              numeric: h.valueType == ValueTypes.Number))
          .toList(),
      rows: widget.data
          .map((d) => DataRow(
              cells: widget.columns
                  .map<DataCell>((h) => DataCell(
                        _getCell(h, d),
                        showEditIcon: !h.readOnly,
                      ))
                  .toList()))
          .toList(),
    );
  }

  Widget _getCell(Property prop, data, {totals: false}) {
    if (prop.isImage) {
      if (data[prop.dbName + 'Id'] == null ||
          data[prop.dbName + 'Id'].toString().isEmpty) {
        return Container();
      }
      return Align(
          alignment: LocalConfigService.isArabic
              ? Alignment.centerRight
              : Alignment.centerLeft,
          child: Image(
              image: ImageService.imageProvider(data[prop.dbName + 'Id']) ??
                  TecfyCoreApp.logo!.image,
              height: 50));
    }

    var val = data[prop.dbName];
    if (totals) {
      if (val == null || val == 0 || val == '' || val == '0') {
        return Container();
      }
    } else {
      if (val == null) {
        return Container();
      }
    }

    Widget widgetValue = Padding(
      padding: EdgeInsets.only(
          top: prop.valueType == ValueTypes.Boolean ? 7 : 0, right: 2, left: 2),
      child: Align(
        alignment: LocalConfigService.isArabic
            ? Alignment.centerRight
            : Alignment.centerLeft,
        child: prop.getDisplayWidget(data),
      ),
    );
    return Padding(
        padding: EdgeInsets.only(
            top: 10.0,
            right: LocalConfigService.isArabic
                ? (((data['_tree_level'] ?? 0) as num).toDouble()) * 10.0
                : 0.0,
            left: LocalConfigService.isArabic
                ? 0.0
                : (((data['_tree_level'] ?? 0) as num).toDouble()) * 10.0),
        child: widgetValue);
  }

  DataColumn _getHeaderCell(
    String text, {
    bool isSelected = false,
    bool numeric = false,
  }) {
    return DataColumn(
        onSort: (columnIndex, ascending) {
          setState(() {
            var p = widget.columns[columnIndex];
            widget.data.sort((a, b) => ascending
                ? a[p.dbName].compareTo(b[p.dbName])
                : b[p.dbName].compareTo(a[p.dbName]));
            sortAscending = ascending;
            sortColumnIndex = columnIndex;
          });
        },
        tooltip: text,
        numeric: numeric,
        label: Text('$text ${isSelected ? '*' : ''}',
            textAlign: TextAlign.start,
            style: TextStyle(
                fontSize: 12,
                fontWeight: isSelected ? FontWeight.bold : FontWeight.normal,
                color: ThemeService.secondryColor)));
  }
}

==> tecfy_core_package-1.0.11.tar.gz: lib/views/components/general/data_table.componenet.dart <==
part of tecfy_core_client_package;

class AppDataTable extends StatefulWidget {
  final List<Map<String, dynamic>> data;
  final List<Property> columns;
  const AppDataTable({Key? key, required this.columns, required this.data})
      : super(key: key);

  @override
  _AppDataTableState createState() => _AppDataTableState();
}

class _AppDataTableState extends State<AppDataTable> {
  bool sortAscending = true;
  int? sortColumnIndex;

  _onEditCell(Property propety, Map<String, dynamic> data) async {
    var result = await PopupPropertyComponent.show(context, propety, data);
    if (result != null) setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scrollbar(
      isAlwaysShown: true,
      showTrackOnHover: true,
      // controller: _controller.scrollController,
      child: SingleChildScrollView(
        //controller: _scrollController,
        // scrollDirection: Axis.horizontal,
        child: DataTable(
          columnSpacing: 1,
          dividerThickness: 0.5,
          horizontalMargin: 1,
          showBottomBorder: false,
          sortAscending: sortAscending,
          sortColumnIndex: sortColumnIndex,
          columns: widget.columns
              .map<DataColumn>((h) => _getHeaderCell(h.nameAr,
                  numeric: h.valueType == ValueTypes.Number))
              .toList(),
          rows: widget.data
              .map((d) => DataRow(
                  cells: widget.columns
                      .map<DataCell>((h) => DataCell(
                            _getCell(h, d),
                            onTap: () => _onEditCell(h, d),
                            showEditIcon: !h.readOnly,
                          ))
                      .toList()))
              .toList(),
        ),
      ),
    );
  }

  Widget _getCell(Property prop, data, {totals: false}) {
    if (prop.isImage) {
      if (data[prop.dbName + 'Id'] == null ||
          data[prop.dbName + 'Id'].toString().isEmpty) {
        return Container();
      }
      return Align(
          alignment: LocalConfigService.isArabic
              ? Alignment.centerRight
              : Alignment.centerLeft,
          child: Image(
              image: ImageService.imageProvider(data[prop.dbName + 'Id']) ??
                  TecfyCoreApp.logo!.image,
              height: 50));
    }

    var val = data[prop.dbName];
    if (totals) {
      if (val == null || val == 0 || val == '' || val == '0') {
        return Container();
      }
    } else {
      if (val == null) {
        return Container();
      }
    }

    Widget widgetValue = Padding(
      padding: EdgeInsets.only(
          top: prop.valueType == ValueTypes.Boolean ? 7 : 0, right: 2, left: 2),
      child: Align(
        alignment: LocalConfigService.isArabic
            ? Alignment.centerRight
            : Alignment.centerLeft,
        child: prop.getDisplayWidget(data),
      ),
    );
    return Padding(
        padding: EdgeInsets.only(
            top: 10.0,
            right: LocalConfigService.isArabic
                ? (((data['_tree_level'] ?? 0) as num).toDouble()) * 10.0
                : 0.0,
            left: LocalConfigService.isArabic
                ? 0.0
                : (((data['_tree_level'] ?? 0) as num).toDouble()) * 10.0),
        child: widgetValue);
  }

  DataColumn _getHeaderCell(String text,
      {bool isSelected = false, bool numeric = false}) {
    return DataColumn(
        onSort: (columnIndex, ascending) {
          setState(() {
            var p = widget.columns[columnIndex];
            widget.data.sort((a, b) => ascending
                ? a[p.dbName].compareTo(b[p.dbName])
                : b[p.dbName].compareTo(a[p.dbName]));
            sortAscending = ascending;
            sortColumnIndex = columnIndex;
          });
        },
        tooltip: text,
        numeric: numeric,
        label: Text('$text ${isSelected ? '*' : ''}',
            textAlign: TextAlign.start,
            style: TextStyle(
                fontSize: 12,
                fontWeight: isSelected ? FontWeight.bold : FontWeight.normal,
                color: ThemeService.secondryColor)));
  }
}
